"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseAuthAPI = exports.AuthApiError = void 0;
const errors_js_1 = require("../lib/errors.js");
const runtime_js_1 = require("../lib/runtime.js");
const client_authentication_js_1 = require("./client-authentication.js");
class AuthApiError extends Error {
    constructor(error, error_description, statusCode, body, headers) {
        super(error_description || error);
        this.error = error;
        this.error_description = error_description;
        this.statusCode = statusCode;
        this.body = body;
        this.headers = headers;
        this.name = 'AuthApiError';
    }
}
exports.AuthApiError = AuthApiError;
async function parseError(response) {
    // Errors typically have a specific format:
    // {
    //    error: 'invalid_body',
    //    error_description: 'Bad Request',
    // }
    const body = await response.text();
    let data;
    try {
        data = JSON.parse(body);
        return new AuthApiError(data.error, data.error_description, response.status, body, response.headers);
    }
    catch (_) {
        return new errors_js_1.ResponseError(response.status, body, response.headers, 'Response returned an error code');
    }
}
class BaseAuthAPI extends runtime_js_1.BaseAPI {
    constructor(options) {
        super({ ...options, baseUrl: `https://${options.domain}`, parseError });
        this.domain = options.domain;
        this.clientId = options.clientId;
        this.clientSecret = options.clientSecret;
        this.clientAssertionSigningKey = options.clientAssertionSigningKey;
        this.clientAssertionSigningAlg = options.clientAssertionSigningAlg;
    }
    /**
     * @private
     */
    async addClientAuthentication(payload, required) {
        return (0, client_authentication_js_1.addClientAuthentication)({
            payload,
            domain: this.domain,
            required,
            clientId: this.clientId,
            clientSecret: this.clientSecret,
            clientAssertionSigningKey: this.clientAssertionSigningKey,
            clientAssertionSigningAlg: this.clientAssertionSigningAlg,
        });
    }
}
exports.BaseAuthAPI = BaseAuthAPI;
//# sourceMappingURL=base-auth-api.js.map