import { ResponseError } from '../lib/errors.js';
import { BaseAPI } from '../lib/runtime.js';
import { addClientAuthentication, } from './client-authentication.js';
export class AuthApiError extends Error {
    constructor(error, error_description, statusCode, body, headers) {
        super(error_description || error);
        this.error = error;
        this.error_description = error_description;
        this.statusCode = statusCode;
        this.body = body;
        this.headers = headers;
        this.name = 'AuthApiError';
    }
}
async function parseError(response) {
    // Errors typically have a specific format:
    // {
    //    error: 'invalid_body',
    //    error_description: 'Bad Request',
    // }
    const body = await response.text();
    let data;
    try {
        data = JSON.parse(body);
        return new AuthApiError(data.error, data.error_description, response.status, body, response.headers);
    }
    catch (_) {
        return new ResponseError(response.status, body, response.headers, 'Response returned an error code');
    }
}
export class BaseAuthAPI extends BaseAPI {
    constructor(options) {
        super({ ...options, baseUrl: `https://${options.domain}`, parseError });
        this.domain = options.domain;
        this.clientId = options.clientId;
        this.clientSecret = options.clientSecret;
        this.clientAssertionSigningKey = options.clientAssertionSigningKey;
        this.clientAssertionSigningAlg = options.clientAssertionSigningAlg;
    }
    /**
     * @private
     */
    async addClientAuthentication(payload, required) {
        return addClientAuthentication({
            payload,
            domain: this.domain,
            required,
            clientId: this.clientId,
            clientSecret: this.clientSecret,
            clientAssertionSigningKey: this.clientAssertionSigningKey,
            clientAssertionSigningAlg: this.clientAssertionSigningAlg,
        });
    }
}
//# sourceMappingURL=base-auth-api.js.map